
`source_content`

# 上記の要件定義を元に、以下の指示に従ってPythonでディレクトリ構成を構築するコードを記述してください。

## 指示
- 処理は含めず、ディレクトリとファイルの構成のみ作成すること
- ディレクトリ構成は `generated/`source_file_name`/` の配下にすべて作成すること
- コードブロックは使用せず、Pythonコードのみを記述すること
- 生成したコードは即座に実行可能な状態にすること
- 出力したディレクトリはリンクを出力すること
